import React, { useState } from 'react'
import DatePicker from 'react-datepicker'
import type { ChecklistItem } from '../types'
import 'react-datepicker/dist/react-datepicker.css'

interface DateConstraintManagerProps {
  item: ChecklistItem
  onSave: (notBefore?: string, notAfter?: string) => void
  onCancel: () => void
}

export const DateConstraintManager: React.FC<DateConstraintManagerProps> = ({
  item,
  onSave,
  onCancel
}) => {
  const [notBefore, setNotBefore] = useState<Date | null>(
    item.not_before ? new Date(item.not_before) : null
  )
  const [notAfter, setNotAfter] = useState<Date | null>(
    item.not_after ? new Date(item.not_after) : null
  )

  const handleSave = () => {
    const notBeforeDate = notBefore ? notBefore.toISOString() : undefined
    const notAfterDate = notAfter ? notAfter.toISOString() : undefined
    onSave(notBeforeDate, notAfterDate)
  }

  const handleClear = () => {
    setNotBefore(null)
    setNotAfter(null)
  }

  const now = new Date()

  return (
    <div className="fixed inset-0 bg-black bg-opacity-50 flex items-center justify-center z-50 p-4">
      <div className="bg-white dark:bg-gray-800 rounded-lg p-6 w-full max-w-md mx-4 max-h-[90vh] overflow-y-auto">
        <div className="flex items-center justify-between mb-4">
          <h3 className="text-lg font-semibold text-gray-900 dark:text-white">Manage Date Constraints</h3>
          <button
            onClick={onCancel}
            className="text-gray-400 hover:text-gray-600 dark:hover:text-gray-300"
          >
            <svg className="w-5 h-5" fill="none" stroke="currentColor" viewBox="0 0 24 24">
              <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M6 18L18 6M6 6l12 12" />
            </svg>
          </button>
        </div>
        
        <p className="text-sm text-gray-600 dark:text-gray-400 mb-6">
          Set when this item can be completed. Leave empty to remove constraints.
        </p>
        
        <div className="space-y-6">
          <div>
            <label className="block text-sm font-medium text-gray-700 dark:text-gray-300 mb-2">
              Not Before (Earliest completion time)
            </label>
            <div className="relative">
              <DatePicker
                selected={notBefore}
                onChange={(date) => setNotBefore(date)}
                showTimeSelect
                timeFormat="HH:mm"
                timeIntervals={15}
                dateFormat="MMMM d, yyyy h:mm aa"
                placeholderText="Select earliest completion time"
                minDate={now}
                isClearable
                className="w-full px-3 py-2 border border-gray-300 dark:border-gray-600 rounded-md focus:outline-none focus:ring-2 focus:ring-blue-500 focus:border-transparent bg-white dark:bg-gray-700 text-gray-900 dark:text-white placeholder-gray-500 dark:placeholder-gray-400"
                popperClassName="z-50"
                popperPlacement="bottom-start"
                customInput={
                  <input
                    className="w-full px-3 py-2 border border-gray-300 dark:border-gray-600 rounded-md focus:outline-none focus:ring-2 focus:ring-blue-500 focus:border-transparent bg-white dark:bg-gray-700 text-gray-900 dark:text-white placeholder-gray-500 dark:placeholder-gray-400"
                  />
                }
              />
              {notBefore && (
                <button
                  onClick={() => setNotBefore(null)}
                  className="absolute right-2 top-1/2 transform -translate-y-1/2 text-gray-400 hover:text-gray-600 dark:hover:text-gray-300"
                >
                  <svg className="w-4 h-4" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                    <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M6 18L18 6M6 6l12 12" />
                  </svg>
                </button>
              )}
            </div>
          </div>
          
          <div>
            <label className="block text-sm font-medium text-gray-700 dark:text-gray-300 mb-2">
              Not After (Latest completion time)
            </label>
            <div className="relative">
              <DatePicker
                selected={notAfter}
                onChange={(date) => setNotAfter(date)}
                showTimeSelect
                timeFormat="HH:mm"
                timeIntervals={15}
                dateFormat="MMMM d, yyyy h:mm aa"
                placeholderText="Select latest completion time"
                minDate={notBefore || now}
                isClearable
                className="w-full px-3 py-2 border border-gray-300 dark:border-gray-600 rounded-md focus:outline-none focus:ring-2 focus:ring-blue-500 focus:border-transparent bg-white dark:bg-gray-700 text-gray-900 dark:text-white placeholder-gray-500 dark:placeholder-gray-400"
                popperClassName="z-50"
                popperPlacement="bottom-start"
                customInput={
                  <input
                    className="w-full px-3 py-2 border border-gray-300 dark:border-gray-600 rounded-md focus:outline-none focus:ring-2 focus:ring-blue-500 focus:border-transparent bg-white dark:bg-gray-700 text-gray-900 dark:text-white placeholder-gray-500 dark:placeholder-gray-400"
                  />
                }
              />
              {notAfter && (
                <button
                  onClick={() => setNotAfter(null)}
                  className="absolute right-2 top-1/2 transform -translate-y-1/2 text-gray-400 hover:text-gray-600 dark:hover:text-gray-300"
                >
                  <svg className="w-4 h-4" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                    <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M6 18L18 6M6 6l12 12" />
                  </svg>
                </button>
              )}
            </div>
          </div>
        </div>

        {/* Preview */}
        {(notBefore || notAfter) && (
          <div className="mt-6 p-4 bg-gray-50 dark:bg-gray-700 rounded-lg">
            <h4 className="text-sm font-medium text-gray-700 dark:text-gray-300 mb-2">Preview:</h4>
            <div className="text-sm text-gray-600 dark:text-gray-400 space-y-1">
              {notBefore && (
                <div>✅ Can complete after: {notBefore.toLocaleString()}</div>
              )}
              {notAfter && (
                <div>✅ Can complete before: {notAfter.toLocaleString()}</div>
              )}
              {notBefore && notAfter && (
                <div className="text-blue-600 dark:text-blue-400 font-medium">
                  Time window: {Math.round((notAfter.getTime() - notBefore.getTime()) / (1000 * 60 * 60 * 24))} days
                </div>
              )}
            </div>
          </div>
        )}

        <div className="flex flex-col sm:flex-row justify-between gap-3 mt-6">
          <button
            onClick={handleClear}
            className="px-4 py-2 text-sm text-gray-600 dark:text-gray-400 hover:text-gray-800 dark:hover:text-gray-200 hover:bg-gray-100 dark:hover:bg-gray-700 rounded-md transition-colors"
          >
            Clear All
          </button>
          <div className="flex gap-2">
            <button
              onClick={onCancel}
              className="px-4 py-2 text-sm text-gray-600 dark:text-gray-400 hover:text-gray-800 dark:hover:text-gray-200 hover:bg-gray-100 dark:hover:bg-gray-700 rounded-md transition-colors"
            >
              Cancel
            </button>
            <button
              onClick={handleSave}
              className="px-4 py-2 text-sm bg-blue-500 text-white rounded-md hover:bg-blue-600 focus:outline-none focus:ring-2 focus:ring-blue-500 focus:ring-offset-2 transition-colors"
            >
              Save
            </button>
          </div>
        </div>
      </div>
    </div>
  )
} 